#
# spec file for package pesign-obs-integration
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


Name:           pesign-obs-integration
Summary:        Macros and scripts to sign the kernel and bootloader
License:        GPL-2.0-only
Group:          Development/Tools/Other
Version:        10.1
Release:        lp152.5.1
Requires:       fipscheck
Requires:       mozilla-nss-tools
Requires:       openssl
%ifarch %ix86 x86_64 ia64 aarch64 %arm
Requires:       pesign
%endif
BuildRequires:  openssl
Url:            http://en.opensuse.org/openSUSE:UEFI_Image_File_Sign_Tools
Source:         %{name}_%{version}.tar.gz
# https://github.com/openSUSE/pesign-obs-integration/commit/028e04a32e619a15c3d66ad57576c6235323f042
Patch0:		0001-sign-stage3.bin-from-s390-tools-with-sign-files-bsc-.patch
Patch1:		pesign-sign-s390x-kernel.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# suse-module-tools <= 15.0.10 contains modsign-verify
Requires:       suse-module-tools >= 15.0.10

%description
This package provides scripts and rpm macros to automate signing of the
boot loader, kernel and kernel modules in the openSUSE Buildservice.

%prep
%setup -D -n %{name}
%patch0 -p1
%patch1 -p1

%build

%install

mkdir -p %buildroot/usr/lib/rpm/brp-suse.d %buildroot/usr/lib/rpm/pesign
install pesign-gen-repackage-spec kernel-sign-file gen-hmac %buildroot/usr/lib/rpm/pesign
install brp-99-pesign %buildroot/usr/lib/rpm/brp-suse.d
# brp-99-compress-vmlinux has nothing to do with signing. It is packaged in
# pesign-obs-integration because this package is already used by the kernel
# build
install brp-99-compress-vmlinux %buildroot/usr/lib/rpm/brp-suse.d
install -m644 pesign-repackage.spec.in %buildroot/usr/lib/rpm/pesign
mkdir -p %buildroot/usr/bin
install modsign-repackage %buildroot/usr/bin/
install -pm 755 modsign-verify %buildroot/usr/bin/
if test -e _projectcert.crt; then
	openssl x509 -inform PEM -in _projectcert.crt \
		-outform DER -out %buildroot/usr/lib/rpm/pesign/pesign-cert.x509
else
	echo "No buildservice project certificate available"
fi

%files
%defattr(-,root,root)
%license COPYING
%doc README
/usr/bin/modsign-repackage
/usr/bin/modsign-verify
/usr/lib/rpm/*

%changelog
* Wed Feb 26 2020 Marcus Meissner <meissner@suse.com>
- pesign-sign-s390x-kernel.patch: allow the s390x kernel with
  kernel-sign-files and not pesign (bsc#1163524)
* Thu Feb 20 2020 Marcus Meissner <meissner@suse.com>
- sign stage3.bin from s390-tools with sign-files (bsc#1163524)
  0001-sign-stage3.bin-from-s390-tools-with-sign-files-bsc-.patch
* Wed Sep  4 2019 Michal Suchanek <msuchanek@suse.com>
- Require pesign on arm (boo#1134303).
* Tue Dec 11 2018 glin@suse.com
- Version 10.1
- Add modsign-verify for the signature verification (bsc#1118953)
* Wed Oct 31 2018 glin@suse.com
- rpm: properly forward dep flags (bsc#1114605)
- Fix new Lintian Error from Debian 10
* Tue Jun 12 2018 glin@suse.com
- debhelper: restrict wildcard package unpacking
* Mon Jun 11 2018 glin@suse.com
- debhelper: fix conffiles corner case
* Fri Jun  8 2018 glin@suse.com
- Remove the unstable source url
- Update the debian scripts
* Mon Jun  4 2018 glin@suse.com
- Switch to tarball release
* Thu Feb 22 2018 glin@suse.com
- Provide password file for 'certutil -A' due to the change in
  mozilla-nss 3.35 (boo#1082235)
* Wed Nov  8 2017 jlee@suse.com
- Modified modsign-repackage, using certificate to try to decrypt
  the signature of kernel module. It can be used to verify the
  integrity of signature.
* Wed Sep 27 2017 jlee@suse.com
- Michael Schröder improved the original kernel-sign-file script to
  support PKCS#7 kernel module signing. Replacing sign-file.c with
  new kernel-sign-file script. (bsc#1049122)
* Sun Sep 24 2017 coolo@suse.com
- escape regexp in pesign-gen-repackage-spec for perl 5.26
* Wed Sep  6 2017 jlee@suse.com
- To support PKCS#7 kernel module signing, copy sign-file.c from
  SLE-15 v4.12 kernel source to replace the kernel-sign-file script
  to align upstream. (bsc#1049122)
* Tue Nov 29 2016 mmarek@suse.cz
- Copy over any *.log files from the first build (bsc#1012422)
* Thu Mar  3 2016 glin@suse.com
- Add aarch64 support since pesign also build on aarch64
* Thu Jan 22 2015 mmarek@suse.cz
- Add support for file verify flags (bnc#905420).
* Thu Jan 22 2015 mmarek@suse.cz
- Sort the parts of the repackage spec file for easier debugging.
* Tue Sep 16 2014 mls@suse.de
- fall back to project cert in the followup spec if it
  exists
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Wed Aug 20 2014 mmarek@suse.cz
- brp-99-compress-vmlinux: Compress the vmlinux image after
  find-debuginfo (bnc#880848, bnc#884459)
* Tue Aug 12 2014 meissner@suse.com
- switch gen-hmac to use fipscheck instead of sha256hmac
* Mon Aug  4 2014 mmarek@suse.cz
- Set BRP_PESIGN_FILES="" in the repackage build to avoid loops.
* Wed Jul 30 2014 mmarek@suse.cz
- Accept also rpmlintrc files without any <package>- prefix.
* Mon Jul 28 2014 mmarek@suse.cz
- Use package's rpmlintrc files in the second build.
* Thu Jul  3 2014 mmarek@suse.cz
- Drop support for signing firmware files (bnc#867199)
* Thu Apr 24 2014 mmarek@suse.cz
- Fix matching /boot and /lib/firmware in pesign-repackage.spec
* Wed Apr 23 2014 mmarek@suse.com
- Do not store the buildroot in the .*.hmac file.
* Wed Apr 23 2014 mmarek@suse.com
- Regenerate the HMAC checksum when signing and EFI binary with
  a checksum (fate#316930, bnc#856310).
* Wed Apr 23 2014 mmarek@suse.com
- Update README.
* Wed Apr 23 2014 mmarek@suse.cz
- Add /usr/lib/rpm/pesign/gen-hmac tool to generate a hmac checksum
  for a given file (fate#316930, bnc#856310).
* Thu Apr  3 2014 ro@suse.de
- pesign-gen-repackage-spec: switch to new rpm style handling
  of weak dependencies
* Thu Jan 16 2014 mmarek@suse.cz
- Do not sign any files if BRP_PESIGN_FILES is set not an empty
  string (bnc#857599).
* Tue Jan  7 2014 mmarek@suse.cz
- Fix a typo in the last change.
* Mon Jan  6 2014 mmarek@suse.cz
- Default to BRP_PESIGN_FILES="*.ko /lib/firmware" (bnc#857599).
* Mon Jan  6 2014 mmarek@suse.cz
- Add --signatures=<directory> option to modsign-repackage
  (bnc#841627).
* Fri Jun 14 2013 mmarek@suse.cz
- Put debuginfo packages to %%_topdir/OTHER (bnc#824971).
* Thu Mar 28 2013 mmarek@suse.cz
- Version 10
- Add modsign-repackage tool to repackage RPMs outside the buildservice
* Tue Mar 26 2013 glin@suse.com
- Calculate the digest of the padded data section to be consistent
  with the output file (bnc#808594, bnc#811325)
* Fri Mar 15 2013 coolo@suse.com
- correct the license of the generated package to fix build
* Tue Mar  5 2013 mmarek@suse.cz
- Do not repackage debuginfo package (bnc#806637)
* Mon Mar  4 2013 mmarek@suse.cz
- Version 9
- Add support for triggers (bnc#806737)
* Wed Feb 20 2013 mmarek@suse.cz
- Do not fail the build if %%_topdir/OTHER cannot be created
* Wed Feb 13 2013 mmarek@suse.cz
- Version 8
- Hide baselibs from post-build-checks
* Wed Feb 13 2013 mmarek@suse.cz
- Do not repackage baselibs
* Wed Feb 13 2013 mmarek@suse.cz
- Version 7
- Fix for scriptlets with empty body
* Tue Feb 12 2013 mls@suse.de
- reduce debugging as pesign is now fixed
* Tue Feb 12 2013 mls@suse.de
- add a bit of debug output to find out why the kernel signatures
  are bad
* Wed Feb  6 2013 mls@suse.de
- switch to normal brp hook
- mv stuff in pesign directory instead of cluttering /usr/lib/rpm
* Fri Feb  1 2013 mls@suse.de
- fix pesign calls
* Fri Feb  1 2013 mmarek@suse.cz
- Add some preliminary code to sign EFI binaries, marked with
  FIXMEs.
* Wed Jan 30 2013 mmarek@suse.cz
- Version 6
- Fix handling packages with NoSource
- Fix for multiple patterns in %%sign_files
* Tue Jan 29 2013 mmarek@suse.cz
- Version 5
- Use newc-style cpio archives, as required by the buildservice.
- Use signing certificates provided by the buildservice.
- Minor fixes.
* Mon Jan 28 2013 mmarek@suse.cz
- Version 4
- Support for firmware signatures.
- Expect the correct archive with signatures (<name>.cpio.rsasign.sig).
- Minor fixes.
* Wed Jan 23 2013 mmarek@suse.cz
- Version 3
- Switch to storing whole files in the *.cpio.rsasign archive.
- Append the signatures to kernel modules.
* Fri Jan 18 2013 mmarek@suse.cz
- Version 2
- Generates another specfile in pesign-repackage.spec to
  be able to copy nearly all RPM tags from the original packages.
- Changed to only store sha256 hashes in the *.cpio.rsasign file,
  instead of whole files.
* Thu Dec 13 2012 mmarek@suse.com
- Created package with macros and scripts to integrate kernel and
  bootloader signing into OBS (fate#314552).
